==> oeshop_0.01.tar.gz: oeshop/admin/prize_admin/category_list.php <==
<?php
//require_once("../admin_auth.php");
if (file_exists("../../lib/connect.php")) { require_once("../../lib/connect.php"); }
require_once("../lib/prize_lib.php");
?>

<!---
OEShop 

:  - ȣ
: E-Mail - compile@dreamwiz.com
: Home - http://www.oe2k.com
:     - з 
:
:  α׷ GNU/GPL  ,  뵵ε    Ǹ   ʽϴ.
: , θ , н,   α׷  񿵸  ο  մϴ.
---->

<html>
<head>
<title>OEShop :::::::::: з </title>
<meta http-equiv='Content-Type' content='text/html; charset=euc-kr'>
<link rel='stylesheet' href='../admin.css' type='text/css'>

<script language='javascript'>
function MM_swapImgRestore() { //v3.0
  var i,x,a=document.MM_sr; for(i=0;a&&i<a.length&&(x=a[i])&&x.oSrc;i++) x.src=x.oSrc;
}

function MM_preloadImages() { //v3.0
  var d=document; if(d.images){ if(!d.MM_p) d.MM_p=new Array();
    var i,j=d.MM_p.length,a=MM_preloadImages.arguments; for(i=0; i<a.length; i++)
    if (a[i].indexOf("#")!=0){ d.MM_p[j]=new Image; d.MM_p[j++].src=a[i];}}
}

function MM_findObj(n, d) { //v4.0
  var p,i,x;  if(!d) d=document; if((p=n.indexOf("?"))>0&&parent.frames.length) {
    d=parent.frames[n.substring(p+1)].document; n=n.substring(0,p);}
  if(!(x=d[n])&&d.all) x=d.all[n]; for (i=0;!x&&i<d.forms.length;i++) x=d.forms[i][n];
  for(i=0;!x&&d.layers&&i<d.layers.length;i++) x=MM_findObj(n,d.layers[i].document);
  if(!x && document.getElementById) x=document.getElementById(n); return x;
}

function MM_swapImage() { //v3.0
  var i,j=0,x,a=MM_swapImage.arguments; document.MM_sr=new Array; for(i=0;i<(a.length-2);i+=3)
   if ((x=MM_findObj(a[i]))!=null){document.MM_sr[j++]=x; if(!x.oSrc) x.oSrc=x.src; x.src=a[i+2];}
}
function del_data(reid, category, pos) {
  var check = confirm(category + " īװ  Ͻðڽϱ?");
  if (!check) { alert("ҵǾϴ."); }
  else { location.href="<?=$PHP_SELF?>?mode=del&depth=<?=$depth?>&sreid=<?=$reid?>&reid=" + reid + "&pos=" + pos; }
}
function open_category(reid, category) {
  window.open("./category_data.php?reid=" + reid + "&category=" + category, "", "width=600, height=400, scrollbars=yes");
}
function text_focus() { FrmCategory.category.focus(); }

function change_view(category_code, depth) {
	document.location.href = "<?=$PHP_SELF?>?category_code=" + category_code + "&depth=" + depth;
	parent.prize_list.document.location.href = "prize_list.php?category_code=" + category_code;
}
</script>
</head>
<body bgcolor="#EFEFEF" text='#000000' marginwidth='0' marginheight='0' leftmargin='0' topmargin='0' onLoad="MM_preloadImages('images/open_folder.gif'); text_focus();">

<?php
// зƮ
if (empty($mode)) {
	// Ŭκ īװ  ´.
	$cl_cat = new read_category($category_code, $depth, $db_conn);

	echo ("
		<table width='100%' border='0' cellpadding='0' cellspacing='1' align='center' bgcolor='#BCBCBC'>
		<tr><td>

		<table width='100%' border='0' cellpadding='0' cellspacing='0' align='center' bgcolor='#FFFFFF'>
		<tr><td>&nbsp;</td><td>&nbsp;</td></tr>
	");

	//  īװ ̵ 
	$t_id = explode("-", $category_code);

	if (sizeof($t_id) > 0) {
		//  зڵ 
		foreach ($t_id as $t_temp) {
			if ($i < sizeof($t_id) - 1) {
				if (empty($t_category_code)) {
					$t_category_code = $t_temp;
				}
				else {
					$t_category_code .= "-".$t_temp;
				}
			}
			$i++;
		}

		// з(category_depth)  1  ֻ зڵ 
		if (sizeof($t_id) == 1) {
			$t_category_code = 0;
		}

		//  з 
		$top_depth = $depth - 1;

		echo ("
			<tr>
			<td style='border-right : solid 1 #000000;'>
			&nbsp;<a href=\"javascript:change_view('$t_category_code', '$top_depth');\"><img src='images/close_folder.gif' border='0'>   īװ</a>
			</td>
			<td>&nbsp;</td>
			</tr>
		");
	}


	//================ зƮ  ================
	while ($row = $cl_cat->get_category()) {
		// īװ  
		if ($row[category_depth] == 1 && $i > 0 && $i < $cl_cat->total - 1) { $img_src = "<img src='images/thread_3.gif' align='absmiddle'>"; }
		elseif ($row[category_depth] == 1 && $i == $cl_cat->total - 1) { $img_src = "<img src='images/thread_2e.gif' align='absmiddle'>"; }
		elseif ($row[category_depth] == 1 && $i == 0) { $img_src = "<img src='images/thread_2.gif' align='absmiddle'>"; }
		elseif ($row[category_depth] > 1) {
			$img_src = "";
			for ($j = 1; $j < $row[category_depth]; $j++) { $img_src .= "<img src='images/thread_line.gif' align='absmiddle'>"; }
			$img_src .= "<img src='images/thread_3.gif' align='absmiddle'>";
		}

		$img_src .= "<img src='images/close_folder.gif' align='absmiddle' name='image$i' border='0'> ";

		// īװ ũ
		if (!$smode) {
			$category_lnk = "<a href=\"javascript:change_view('$row[category_code]', '$row[category_depth]');\"> $row[category_name][$row[category_code]]</a>";
		}
		elseif ($smode == "edit") {
			$category_lnk = "$row[category_name][$row[category_code]]";
		}

		echo ("
			<tr onMouseOver=\"this.style.backgroundColor='#E1E8FF'; MM_swapImage('Image$i','','images/open_folder.gif',1)\" onMouseOut=\"this.style.backgroundColor='#FFFFFF'; MM_swapImgRestore()\">
			<td>
			&nbsp;$img_src$category_lnk
			</td>
			<td align='right'>
		");

		if ($snum > 0) {
			echo "<a href=\"javascript:open_category('$row[reid]' ,'$row[category]');\"><img src='images/open.jpg' border='0'></a>";
		}

		echo ("
			<a href='$PHP_SELF?smode=edit&sreid=$row[reid]&depth=$depth&reid=$reid&scategory=$row[category]'><img src='images/edit.jpg' border='0' alt=''></a>
			<a href=\"javascript:del_data('$row[reid]', '$row[category]', '$row[pos]')\"><img src='images/del.jpg' border='0' alt=''></a>
			</td>
			</tr>
		");
	}

	echo ("
		</table>
	");

	if (empty($smode)) {
		if ($category_code > 0) { $hidden_data = "<input type='hidden' name='tcategory' value='yes'>"; }
		else { $hidden_data = "<input type='hidden' name='tcategory' value='N/A'>"; }

		echo ("
			<form method='post' name='FrmCategory' action='$PHP_SELF'>
			<input type='hidden' name='mode' value='save'>
			<input type='hidden' name='category_code' value='$category_code'>
			<input type='hidden' name='depth' value='$depth'>
			$hidden_data

			<table width='100%' border='0' cellpadding='0' cellspacing='0' align='center' bgcolor='#FFFFFF'>
			<tr><td>&nbsp;</td></tr>
			<tr><td align='center'>
			<u>īװ ¹ : <font color='red'>īװ</font>[<font color='red'>īװڵ</font>]</u>
			<br>
			 īװ : <input type='text' name='category_name' value='$scategory'>
			<input type='submit' value=''>
			</td></tr>
			<tr><td bgcolor='#FFFFFF'>&nbsp;</td></tr>
			</table>

			</td></tr>
			</table>
			</form>
		");
	}
	elseif ($smode == "edit") {
		echo ("
			<form method='post' name='FrmCategory' action='$PHP_SELF'>
			<input type='hidden' name='mode' value='edit'>
			<input type='hidden' name='sreid' value='$sreid'>
			<input type='hidden' name='reid' value='$reid'>
			<input type='hidden' name='depth' value='$depth'>
			<table width='600' border='0' cellpadding='0' cellspacing='0' align='center'>
			<tr><td align='right'>
			īװ  <input type='text' name='category' value='$scategory' class='text'>
			<input type='submit' value='Ϸ' class='button'>
			<input type='button' value='' onClick='javascript:history.go(-1);' class='button'>
			</td></tr>
			</table>
			</form>
		");
	}
}
elseif ($mode == "save") {
	if (empty($tcategory)) { $tcategory = "N/A"; }
	if (empty($category)) { err_msg(" īװ Է ֽñ ٶϴ."); exit; }

	if ($tcategory != "N/A") {
		$query_pos = "select * from foxshop_category where reid='$reid'";
		$result_pos = @mysql_query($query_pos, $connect);

		if (!$result_pos) { err_msg("īװ ġ ã Ͽϴ."); exit; }
		else { $row_pos = mysql_fetch_array($result_pos, $connect); }
		$sdepth = $row_pos[depth] + 1;

		//  Ǻ ū   1 Ų.
		mysql_query("update foxshop_category set pos = pos + 1 where pos > $row_pos[pos] where reid like '$reid-%' and depth='$sdepth'", $connect);

		// (depth), , ġ
		$thread = $row_pos[thread];
		$pos = $row_pos[pos] + 1;
		$result_reid = @mysql_query("select MAX(reid) from foxshop_category where reid like '$row_pos[reid]-%'", $connect);
		$row_reid = mysql_fetch_array($result_reid);
		$temp_reid = explode("-", $row_reid[0]);
		$temp_rnum = sizeof($temp_reid);
		$total_reid = $temp_reid[$temp_rnum - 1];
		$total_reid = $total_reid + 1;

		if ($total_reid < 10) { $total_reid = "0".$total_reid; }
		$sreid = $row_pos[reid]."-".$total_reid;
	}
	else {
		// ū  ã
		$query_thread = "select MAX(thread) from foxshop_category";
		$result_thread = @mysql_query($query_thread, $connect);

		if (!$result_thread) { err_msg("$err<br>ο 带 ã Ͽϴ."); exit; }
		else {
			$row_thread = mysql_fetch_array($result_thread);
			$thread = $row_thread[0] + 1;
		}

		//  Ʈ
		mysql_query("update foxshop_category set pos = pos + 1 where pos > 0", $connect);

		// (depth), 
		$sdepth = 1;
		$pos = 1;

		if ($thread < 10) { $sreid = "0".$thread; }
		else { $sreid = $thread; }
	}

	$query = "insert into foxshop_category values('', '$category', '$pos', '$sdepth', '$thread', '$sreid');";
	$result = @mysql_query($query, $connect);
	if (!$result) { err_msg("īװ ߰  ϴ!"); exit; }
	else { echo "<meta http-equiv='refresh' content='0;url=$PHP_SELF?reid=$reid&depth=$depth'>"; }
}
elseif ($mode == "edit") {
	$query = "update foxshop_category_data set category='$category' where reid='$sreid'";
	$result = @mysql_query($query, $connect);
	$query = "update foxshop_category set category='$category' where reid='$sreid'";
	$result = @mysql_query($query, $connect);

	if (!$result) { err_msg("īװ Ʈ   ϴ! ͺ̽ Դϴ."); exit; }
	else { echo "<meta http-equiv='refresh' content='0;url=$PHP_SELF?reid=$reid&depth=$depth'>"; }
}
elseif ($mode == "del") {
	$result_up = @mysql_query("update foxshop_category set pos = pos - 1 where pos > $pos and depth=$depth", $connect);
	$query = "delete from foxshop_category where reid='$reid'";
	$result = @mysql_query($query, $connect);

	if (!$result) { err_msg("īװ    ϴ! ͺ̽ Դϴ."); exit; }
	$query = "delete from foxshop_category where reid like '$reid-%'";
	$result = @mysql_query($query, $connect);

	if (!$result) { err_msg("Ϻ īװ    ϴ! ͺ̽ Դϴ."); exit; }
	$query = "delete from foxshop_category_data where reid='$reid'";
	$result = @mysql_query($query, $connect);

	if (!$result) { err_msg("īװ͸    ϴ! ͺ̽ Դϴ."); exit; }
	$query = "delete from foxshop_category_data where reid like '$reid-%'";
	$result = @mysql_query($query, $connect);

	if (!$result) { err_msg("Ϻ īװ͸    ϴ! ͺ̽ Դϴ."); exit; }
	else { echo "<meta http-equiv='refresh' content='0;url=$PHP_SELF?reid=$sreid&depth=$depth'>"; }
}
?>

</body>
</html>

==> oeshop_0.03.tar.gz: oeshop/admin/prize_admin/category_list.php <==
<?php
//require_once("../admin_auth.php");
if (file_exists("../../lib/connect.php")) { require_once("../../lib/connect.php"); }
require_once("../lib/prize_lib.php");
?>

<!---
OEShop 

:  - ȣ
: E-Mail - compile@dreamwiz.com
: Home - http://www.oe2k.com
:     - з 
:
:  α׷ GNU/GPL  ,  뵵ε    Ǹ   ʽϴ.
: , θ , н,   α׷  񿵸  ο  մϴ.
---->

<html>
<head>
<title>OEShop :::::::::: з </title>
<meta http-equiv='Content-Type' content='text/html; charset=euc-kr'>
<link rel='stylesheet' href='../admin.css' type='text/css'>

<script language='javascript'>
function del_data(reid, category, pos) {
  var check = confirm(category + " īװ  Ͻðڽϱ?");
  if (!check) { alert("ҵǾϴ."); }
  else { location.href="<?=$PHP_SELF?>?mode=del&depth=<?=$depth?>&sreid=<?=$reid?>&reid=" + reid + "&pos=" + pos; }
}
function open_category(reid, category) {
  window.open("./category_data.php?reid=" + reid + "&category=" + category, "", "width=600, height=400, scrollbars=yes");
}

function change_view(category_code, depth) {
	document.location.href = "<?=$PHP_SELF?>?category_code=" + category_code + "&depth=" + depth;
	parent.prize_list.document.location.href = "prize_list.php?category_code=" + category_code;
}
</script>
</head>
<body bgcolor="#EFEFEF" text='#000000' marginwidth='0' marginheight='0' leftmargin='0' topmargin='0'>

<?php
// зƮ
if (empty($mode)) {
	// Ŭκ īװ  ´.
	$cl_cat = new read_category($HTTP_GET_VARS[category_code], $HTTP_GET_VARS[depth], $db_conn);

	echo ("
		<table width='100%' border='0' cellpadding='0' cellspacing='0' align='center' bgcolor='#FFFFFF' style='border : solid 1 #BCBCBC;'>
		<tr><td>&nbsp;</td><td>&nbsp;</td></tr>
	");

	//  īװ ̵ 
	$t_id = explode("-", $HTTP_GET_VARS[category_code]);

	if (sizeof($t_id) > 0) {
		//  зڵ 
		foreach ($t_id as $t_temp) {
			if ($i < sizeof($t_id) - 1) {
				if (empty($t_category_code)) {
					$t_category_code = $t_temp;
				}
				else {
					$t_category_code .= "-".$t_temp;
				}
			}
			$i++;
		}

		// з(category_depth)  1  ֻ зڵ 
		if (sizeof($t_id) == 1) {
			$t_category_code = 0;
		}

		//  з 
		$top_depth = $HTTP_GET_VARS[depth] - 1;

		echo ("
			<tr>
			<td>
			&nbsp;<a href=\"javascript:change_view('$t_category_code', '$top_depth');\"><img src='images/close_folder.gif' border='0'>   īװ</a>
			</td>
			<td>&nbsp;</td>
			</tr>
		");
	}


	//================ зƮ  ================
	while ($row = $cl_cat->get_category()) {
		// īװ  
		if ($row[category_depth] == 1 && $i > 0 && $i < $cl_cat->total - 1) { $img_src = "<img src='images/thread_3.gif' align='absmiddle'>"; }
		elseif ($row[category_depth] == 1 && $i == $cl_cat->total - 1) { $img_src = "<img src='images/thread_2e.gif' align='absmiddle'>"; }
		elseif ($row[category_depth] == 1 && $i == 0) { $img_src = "<img src='images/thread_2.gif' align='absmiddle'>"; }
		elseif ($row[category_depth] > 1) {
			$img_src = "";
			for ($j = 1; $j < $row[category_depth]; $j++) { $img_src .= "<img src='images/thread_line.gif' align='absmiddle'>"; }
			$img_src .= "<img src='images/thread_3.gif' align='absmiddle'>";
		}

		$img_src .= "<img src='images/close_folder.gif' align='absmiddle' name='image$i' border='0'> ";

		// īװ ũ
		if (!$smode) {
			$category_lnk = "<a href=\"javascript:change_view('$row[category_code]', '$row[category_depth]');\"> $row[category_name][$row[category_code]]</a>";
		}
		elseif ($smode == "edit") {
			$category_lnk = "$row[category_name][$row[category_code]]";
		}

		echo ("
			<tr onMouseOver=\"this.style.backgroundColor='#E1E8FF';\" onMouseOut=\"this.style.backgroundColor='#FFFFFF';\">
			<td>
			&nbsp;$img_src$category_lnk
			</td>
			<td align='right'>
		");

		if ($snum > 0) {
			echo "<a href=\"javascript:open_category('$row[reid]' ,'$row[category]');\"><img src='images/open.jpg' border='0'></a>";
		}

		echo ("
			<a href='$PHP_SELF?smode=edit&sreid=$row[reid]&depth=$depth&reid=$reid&scategory=$row[category]'><img src='images/edit.jpg' border='0' alt=''></a>
			<a href=\"javascript:del_data('$row[reid]', '$row[category]', '$row[pos]')\"><img src='images/del.jpg' border='0' alt=''></a>
			</td>
			</tr>
		");
	}

	echo ("
		<tr><td>&nbsp;</td></tr>
		</table>
	");

	if (empty($smode)) {
		if ($category_code > 0) { $hidden_data = "<input type='hidden' name='tcategory' value='yes'>"; }
		else { $hidden_data = "<input type='hidden' name='tcategory' value='N/A'>"; }

		echo ("
			<form method='post' name='FrmCategory' action='$PHP_SELF'>
			<input type='hidden' name='mode' value='save'>
			<input type='hidden' name='category_code' value='$category_code'>
			<input type='hidden' name='depth' value='$depth'>
			$hidden_data

			<table width='100%' border='0' cellpadding='0' cellspacing='0' align='center' bgcolor='#FFFFFF'>
			<tr><td bgcolor='#FFFFFF'>&nbsp;</td></tr>
			<tr><td align='center'>
			<u>īװ ¹ : <font color='red'>īװ</font>[<font color='red'>īװڵ</font>]</u>
			<br>
			 īװ : <input type='text' name='category_name' value='$scategory'>
			<input type='submit' value=''>
			</td></tr>
			<tr><td bgcolor='#FFFFFF'>&nbsp;</td></tr>
			</table>
			</form>
		");
	}
	elseif ($smode == "edit") {
		echo ("
			<form method='post' name='FrmCategory' action='$PHP_SELF'>
			<input type='hidden' name='mode' value='edit'>
			<input type='hidden' name='sreid' value='$sreid'>
			<input type='hidden' name='reid' value='$reid'>
			<input type='hidden' name='depth' value='$depth'>
			<table width='600' border='0' cellpadding='0' cellspacing='0' align='center'>
			<tr><td align='right'>
			īװ  <input type='text' name='category' value='$scategory' class='text'>
			<input type='submit' value='Ϸ' class='button'>
			<input type='button' value='' onClick='javascript:history.go(-1);' class='button'>
			</td></tr>
			</table>
			</form>
		");
	}
}
elseif ($mode == "save") {
	if (empty($tcategory)) { $tcategory = "N/A"; }
	if (empty($category)) { err_msg(" īװ Է ֽñ ٶϴ."); exit; }

	if ($tcategory != "N/A") {
		$query_pos = "select * from foxshop_category where reid='$reid'";
		$result_pos = @mysql_query($query_pos, $connect);

		if (!$result_pos) { err_msg("īװ ġ ã Ͽϴ."); exit; }
		else { $row_pos = mysql_fetch_array($result_pos, $connect); }
		$sdepth = $row_pos[depth] + 1;

		//  Ǻ ū   1 Ų.
		mysql_query("update foxshop_category set pos = pos + 1 where pos > $row_pos[pos] where reid like '$reid-%' and depth='$sdepth'", $connect);

		// (depth), , ġ
		$thread = $row_pos[thread];
		$pos = $row_pos[pos] + 1;
		$result_reid = @mysql_query("select MAX(reid) from foxshop_category where reid like '$row_pos[reid]-%'", $connect);
		$row_reid = mysql_fetch_array($result_reid);
		$temp_reid = explode("-", $row_reid[0]);
		$temp_rnum = sizeof($temp_reid);
		$total_reid = $temp_reid[$temp_rnum - 1];
		$total_reid = $total_reid + 1;

		if ($total_reid < 10) { $total_reid = "0".$total_reid; }
		$sreid = $row_pos[reid]."-".$total_reid;
	}
	else {
		// ū  ã
		$query_thread = "select MAX(thread) from foxshop_category";
		$result_thread = @mysql_query($query_thread, $connect);

		if (!$result_thread) { err_msg("$err<br>ο 带 ã Ͽϴ."); exit; }
		else {
			$row_thread = mysql_fetch_array($result_thread);
			$thread = $row_thread[0] + 1;
		}

		//  Ʈ
		mysql_query("update foxshop_category set pos = pos + 1 where pos > 0", $connect);

		// (depth), 
		$sdepth = 1;
		$pos = 1;

		if ($thread < 10) { $sreid = "0".$thread; }
		else { $sreid = $thread; }
	}

	$query = "insert into foxshop_category values('', '$category', '$pos', '$sdepth', '$thread', '$sreid');";
	$result = @mysql_query($query, $connect);
	if (!$result) { err_msg("īװ ߰  ϴ!"); exit; }
	else { echo "<meta http-equiv='refresh' content='0;url=$PHP_SELF?reid=$reid&depth=$depth'>"; }
}
elseif ($mode == "edit") {
	$query = "update foxshop_category_data set category='$category' where reid='$sreid'";
	$result = @mysql_query($query, $connect);
	$query = "update foxshop_category set category='$category' where reid='$sreid'";
	$result = @mysql_query($query, $connect);

	if (!$result) { err_msg("īװ Ʈ   ϴ! ͺ̽ Դϴ."); exit; }
	else { echo "<meta http-equiv='refresh' content='0;url=$PHP_SELF?reid=$reid&depth=$depth'>"; }
}
elseif ($mode == "del") {
	$result_up = @mysql_query("update foxshop_category set pos = pos - 1 where pos > $pos and depth=$depth", $connect);
	$query = "delete from foxshop_category where reid='$reid'";
	$result = @mysql_query($query, $connect);

	if (!$result) { err_msg("īװ    ϴ! ͺ̽ Դϴ."); exit; }
	$query = "delete from foxshop_category where reid like '$reid-%'";
	$result = @mysql_query($query, $connect);

	if (!$result) { err_msg("Ϻ īװ    ϴ! ͺ̽ Դϴ."); exit; }
	$query = "delete from foxshop_category_data where reid='$reid'";
	$result = @mysql_query($query, $connect);

	if (!$result) { err_msg("īװ͸    ϴ! ͺ̽ Դϴ."); exit; }
	$query = "delete from foxshop_category_data where reid like '$reid-%'";
	$result = @mysql_query($query, $connect);

	if (!$result) { err_msg("Ϻ īװ͸    ϴ! ͺ̽ Դϴ."); exit; }
	else { echo "<meta http-equiv='refresh' content='0;url=$PHP_SELF?reid=$sreid&depth=$depth'>"; }
}
?>

</body>
</html>
